==> ui-jquery-5.1.0.tgz: package/README.md <==
# @easyquery/ui-jquery (part of EasyQuery.JS)
EasyQuery library provides you with the means to add an ad-hoc reporting or advanced search functionality to your web application.

It gives you a simple to use but a quite powerful user interface to build queries or filters to your data. Your end-users will get the power of SQL with the simplicity of a natural language.

Take a look at [EasyQuery web-page](https://korzh.com/easyquery) for more information.

This `ui-jquery` package defines the implementation of some EasyQuery UI widgets which are based on JQuery UI widgets (and so depends on JQuery and JQuery UI packages).    
This package depends on `@easyquery/core`, `easyquery/broker-eqs` and `@easyquery/ui` packages.

> __NB__: Using JQuery is a temporal solution. Feature version of EasyQuery.JS  most possibly will not use JQuery for the implementation of UI components. Instead there will be 'vanilla JS' UI controls in `@easyquery/ui` package and additional packages with the wrappers for the most popular frameworks (Angular, React, Vue, etc).


# Usage
`@easyquery/ui-jquery` is used together with other [EasyQuery packages](https://www.npmjs.com/org/easyquery) and some server-side code which is responsible for query generation and data retrieving.

We have a few [Getting Started tutorials](https://korzh.com/easyquery/docs/version-5-0) of using EasyQuery packages together with ASP.NET Core backend. 

For other platforms, you will also need a special EasyQuery Server which can be installed on any Linux, Windows or Mac server. For more information please read [How EasyQuery works](https://korzh.com/easyquery/javascript#HDIW) section on EasyQuery.JS web page.


# Live example
You can test EasyQuery in several different scenarios on our [live demos page](http://demo.easyquerybuilder.com).

The source code for these sample web-applications is available on [GitHub](https://github.com/easyquery/AspNetCoreSamples).

# Documentation
 * [Getting started articles](https://korzh.com/easyquery/javascript/docs/getting-started)
 * [Tutorials](https://korzh.com/easyquery/javascript/docs/tutorials)
 * [API Reference)(https://korzh.com/easyquery/javascript/docs/api-reference)

# License
The package is distributed under LGPL-3.0 license.

The server-side part (which is required to build a working solution) is licensed separately. 
For more information please see [EasyQuery Licensing](https://korzh.com/easyquery/licensing) page.

==> ui-jquery-5.1.11.tgz: package/README.md <==
# @easyquery/ui-jquery (part of EasyQuery.JS)

EasyQuery library provides you with the means to add an ad-hoc reporting or advanced search functionality to your web application.

It gives you a simple to use but a quite powerful user interface to build queries or filters to your data. Your end-users will get the power of SQL with the simplicity of a natural language.

Take a look at [EasyQuery web-page](https://korzh.com/easyquery) for more information.

This `ui-jquery` package defines the implementation of some EasyQuery UI widgets which are based on JQuery UI widgets (and so depends on JQuery and JQuery UI packages).

This package depends on `@easyquery/core`, `easyquery/broker-eqs` and `@easyquery/ui` packages.

> __NB__: Using JQuery is a temporal solution. Feature version of EasyQuery.JS  most possibly will not use JQuery for the implementation of UI components. Instead there will be 'vanilla JS' UI controls in `@easyquery/ui` package and additional packages with the wrappers for the most popular frameworks (Angular, React, Vue, etc).

## Usage

`@easyquery/ui-jquery` is used together with other [EasyQuery packages](https://www.npmjs.com/org/easyquery) and some server-side code which is responsible for query generation and data retrieving.

We have a few [Getting Started tutorials](https://korzh.com/easyquery/docs/getting-started/version-5-x) of using EasyQuery packages together with ASP.NET Core backend.

For other platforms, you will also need a special EasyQuery Server which can be installed on any Linux, Windows or Mac server. For more information please read [How EasyQuery works](https://korzh.com/easyquery/javascript#HDIW) section on EasyQuery.JS web page.

## Live example

You can test EasyQuery in several different scenarios on our [live demos page](https://korzh.com/demo/easyquery-asp-net-core-razor).

The source code for these sample web-applications is available on [GitHub](https://github.com/easyquery/AspNetCoreSamples).

## Documentation

* [Getting started articles](https://korzh.com/easyquery/javascript/docs/getting-started)
* [Tutorials](https://korzh.com/easyquery/javascript/docs/tutorials)
* [API Referenc](https://korzh.com/easyquery/javascript/docs/api-reference)

## License

The package is distributed under LGPL-3.0 license.

The server-side part (which is required to build a working solution) is licensed separately.
For more information please see [EasyQuery Licensing](https://korzh.com/easyquery/licensing) page.
